/*global define,window*/

define([
    'testsuite/qunit',
    'jquery',
    'ep',
    'testsuite/qunit-fixture!de_epages/paymenttypes/inc/validatesepadata-test',
    'de_epages/paymenttypes/inc/validatesepadata'
], function (QUnit, $, ep, fixture, validateSepaData) {

    ep.ajax = function (o) {
        var result = $.Deferred();

        if (o.data && o.data.ChangeAction === 'JSONValidateSEPAData') {
            if (o.data.BankCode === '123456' || o.data.BankAccountNo === '1234567890') {
                result.reject(
                    result,
                    'error',
                    [
                        {
                            "Reason" : "FORMAT_NOT_BIC",
                            "Value" : "123456",
                            "Message" : "",
                            "Name" : "BIC",
                            "Form" : "ValidateSEPAData"
                        },
                        {
                            "Reason" : "FORMAT_NOT_IBAN",
                            "Value" : "1234567890",
                            "Message" : "",
                            "Name" : "IBAN",
                            "Form" : "ValidateSEPAData"
                        }
                    ]
                );
            } else {
                result.resolve();
            }
        }
        return result;
    };

    QUnit.module('de_epages/paymenttypes/inc/validatesepadata', {
        setup: function () {
            fixture.init();

            validateSepaData(
                $('#IBANBICWarnMessage'),
                $('#SEPAWarnMessage'),
                $('input[name="BankAccountNo"]'),
                $('input[name="BankCode"]'),
                $('button.DoOrder'),
                'Continue anyway'
            );
        },
        teardown: fixture.destroy
    });

    QUnit.test('Check for wrong values', 6, function () {
        var SEPAWarnMessage = $('#SEPAWarnMessage'),
            IBANBICWarnMessage = $('#IBANBICWarnMessage'),
            accountNo = $('input[name="BankAccountNo"]'),
            bankCode = $('input[name="BankCode"]'),
            nextButton = $('button.DoOrder');

        QUnit.strictEqual(
            SEPAWarnMessage.length,
            1,
            'Sepa warn message is visible before something happens'
        );

        accountNo.val('1234567890');
        bankCode.val('123456');
        nextButton.trigger('click');

        QUnit.strictEqual(
            SEPAWarnMessage.is(':visible'),
            false,
            'Sepa warn message was removed after values were changed and the "Continue" button was clicked'
        );

        QUnit.strictEqual(
            IBANBICWarnMessage.is(':visible'),
            true,
            'A message about IBAN and BIC appeared'
        );

        QUnit.strictEqual(
            accountNo.hasClass('ui-warn'),
            true,
            'The input field for IBAN (bank account number) is highlighted'
        );

        QUnit.strictEqual(
            bankCode.hasClass('ui-warn'),
            true,
            'The input field for BIC (bank code) is highlighted'
        );

        QUnit.strictEqual(
            nextButton.text(),
            'Continue anyway',
            'The label of the next button changed'
        );
    });

    QUnit.test('Check for valid values', function () {
        var SEPAWarnMessage = $('#SEPAWarnMessage'),
            IBANBICWarnMessage = $('#IBANBICWarnMessage'),
            accountNo = $('input[name="BankAccountNo"]'),
            bankCode = $('input[name="BankCode"]'),
            nextButton = $('button.DoOrder');

        accountNo.val('DE89370400440532013000');
        bankCode.val('UWSWCHZA80A');
        nextButton.trigger('click');

        QUnit.strictEqual(
            IBANBICWarnMessage.is(':visible'),
            false,
            'A message about IBAN and BIC does not appear because the data is valid'
        );

        QUnit.strictEqual(
            accountNo.hasClass('ui-warn'),
            false,
            'The input field for IBAN (bank account number) is not highlighted'
        );

        QUnit.strictEqual(
            bankCode.hasClass('ui-warn'),
            false,
            'The input field for BIC (bank code) is not highlighted'
        );

        QUnit.strictEqual(
            nextButton.text(),
            'Continue',
            'The label of the next button has not changed'
        );

    });

});